@@ -6,12 +6,12 @@ use warnings;
 
 use Error::Pure qw(err);
 use List::Util qw(none);
-use Locale::Language;
+use Wikibase::Datatype::Languages qw(all_language_codes);
 use Readonly;
 
 Readonly::Array our @EXPORT_OK => qw(check_entity check_language check_lexeme check_property);
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 sub check_entity {
 	my ($self, $key) = @_;
@@ -269,7 +269,6 @@ Returns undef.
 L<Exporter>,
 L<Error::Pure>,
 L<List::Util>,
-L<Locale::Language>,
 L<Readonly>.
 
 =head1 SEE ALSO
@@ -300,6 +299,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.20
+0.21
 
 =cut
